@@ -66,11 +66,26 @@ def test_data_producer_empty_url():
         _ = OpenTelemetryDataProducer()
 
 
+@pytest.mark.parametrize(
+    "set_custom_queue_params",
+    [
+        {},
+        {
+            "UTF_QUEUE_USERNAME": "utfsilabs",
+            "UTF_QUEUE_PASSWORD": "utfsilabs",
+            "UTF_QUEUE_HOSTNAME": "ateaus002d.silabs.com",
+            "UTF_QUEUE_SCHEME": "amqp",
+            "UTF_QUEUE_PORT": "5672",
+            "UTF_QUEUE_VIRTUAL_HOST": "%2f",
+        },
+    ],
+    indirect=True,
+)
 def test_data_producer_central_queue(
     request,
     amqp_url,
     queue_consumer,
-):
+):  # noqa
     producer = OpenTelemetryDataProducer(
         url=amqp_url, producer_app_id=request.node.name
     )
